import { defineUserConfig } from 'vuepress'
import { viteBundler } from '@vuepress/bundler-vite'
import { getDirname, path } from '@vuepress/utils'
import { registerComponentsPlugin } from '@vuepress/plugin-register-components'
import { hopeTheme } from 'vuepress-theme-hope'

const __dirname = getDirname(import.meta.url)

export default defineUserConfig({
  lang: 'en-US',
  title: false,
  description: 'My iGEM Wiki',
  dest: 'public',
  base: "/msp-maastricht/",
  theme: hopeTheme({
    logo: 'https://static.igem.wiki/teams/5306/logo-linear.png',
    home: "/",
    navbar: [
      { text: 'Home', link: '/' },
      { 
        text: 'Team',
        children: [
          { text: 'Team', link: '/team' },
          { text: 'Attributions', link: '/attributions' },
          { text: 'Sponsors', link: '/sponsors'},
        ]
      },
      { 
        text: 'Project',
        children: [
          { text: 'Contribution', link: '/contribution' },
          { text: 'Description', link: '/description' },
          { text: 'Engineering', link: '/engineering'},
          { text: 'Kill switch', link: '/kill-switch'},
        ]
      },
      { text: 'Human Practices', link: '/human-practices' },
      { 
        text: 'Awards',
        children: [
          { text: 'Education', link: '/education' },
          { text: 'Sustainable', link: '/sustainable' },
          { text: 'Part Collection', link: '/part-collection' },
        ]
      },
    ],
    sidebar: {
      // Disable sidebar on the team page
      '/team': false,
      // Enable sidebar on all other pages
    },
    headerDepth: 1
  },
  {
    custom: true,
  }),
  bundler: viteBundler({
    viteOptions: {},
    vuePluginOptions: {},
  }),
  plugins: [
    registerComponentsPlugin({
      componentsDir: path.resolve(__dirname, './components'),
    }),
  ],
  alias: {
    "@theme-hope/components/PageFooter": path.resolve(
      __dirname, "./components/CustomFooter.vue"
    )
  },
  
  head: [
    ['link', { rel: 'icon', href: 'https://static.igem.wiki/teams/5306/natronaut-logo-no-text.png' }],
  ],

  styles: [
    path.resolve(__dirname, './styles/index.scss'),
  ],
  
})
